Coverage for /Users/eugene/Development/legion-utils/legion_utils/checkin_pb2.py: 0%

1# -*- coding: utf-8 -*-

2# Generated by the protocol buffer compiler. DO NOT EDIT!

3# source: checkin.proto

4"""Generated protocol buffer code."""

5 from google.protobuf import descriptor as _descriptor

6 from google.protobuf import descriptor_pool as _descriptor_pool

7 from google.protobuf import symbol_database as _symbol_database

8 from google.protobuf.internal import builder as _builder

9# @@protoc_insertion_point(imports)

10

11 _sym_db = _symbol_database.Default()

12

13

14

15

16 DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rcheckin.proto\"\x95\x01\n\x0e\x43heckInRequest\x12\x1b\n\x13next_checkin_before\x18\x01 \x01(\r\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x12\n\nwarn_after\x18\x03 \x01(\x05\x12\x13\n\x0b\x65rror_after\x18\x04 \x01(\x05\x12\x16\n\x0e\x63ritical_after\x18\x05 \x01(\x05\x12\x11\n\talert_ttl\x18\x06 \x01(\x05\x32\x37\n\x08Princeps\x12+\n\x07\x43heckIn\x12\x0f.CheckInRequest\x1a\x0f.CheckInRequestb\x06proto3')

17

18 _globals = globals()

19 _builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)

20 _builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'checkin_pb2', _globals)

21 if _descriptor._USE_C_DESCRIPTORS == False:

22 DESCRIPTOR._options = None

23 _globals['_CHECKINREQUEST']._serialized_start=18

24 _globals['_CHECKINREQUEST']._serialized_end=167

25 _globals['_PRINCEPS']._serialized_start=169

26 _globals['_PRINCEPS']._serialized_end=224

27# @@protoc_insertion_point(module_scope)